==> pointpos_api-0.0.1.tar.gz: docs/IngredientCategoryApi.md <==
# swagger.api.IngredientCategoryApi

## Load the API package
```dart
import 'package:swagger/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createIngredientcategory**](IngredientCategoryApi.md#createIngredientcategory) | **POST** /ingredient-category | Create Ingredientcategory
[**deleteIngredientcategoryByID**](IngredientCategoryApi.md#deleteIngredientcategoryByID) | **DELETE** /ingredient-category/{id} | Delete Ingredientcategory By ID
[**findIngredientcategory**](IngredientCategoryApi.md#findIngredientcategory) | **GET** /ingredient-category | Get Ingredientcategory List
[**getIngredientcategoryByID**](IngredientCategoryApi.md#getIngredientcategoryByID) | **GET** /ingredient-category/{id} | Get Ingredientcategory By ID
[**updateIngredientcategoryByID**](IngredientCategoryApi.md#updateIngredientcategoryByID) | **PUT** /ingredient-category/{id} | Update Ingredientcategory By ID


# **createIngredientcategory**
> IngredientCategory createIngredientcategory(authorization, xAPIKey, body)

Create Ingredientcategory

Create Ingredientcategory

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new IngredientCategory(); // IngredientCategory | 

try { 
    var result = api_instance.createIngredientcategory(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->createIngredientcategory: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**IngredientCategory**](IngredientCategory.md)|  | 

### Return type

[**IngredientCategory**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteIngredientcategoryByID**
> deleteIngredientcategoryByID(authorization, xAPIKey, id)

Delete Ingredientcategory By ID

Delete Ingredientcategory By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    api_instance.deleteIngredientcategoryByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->deleteIngredientcategoryByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findIngredientcategory**
> List<IngredientCategory> findIngredientcategory(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Ingredientcategory List

Get Ingredientcategory  List

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findIngredientcategory(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->findIngredientcategory: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<IngredientCategory>**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getIngredientcategoryByID**
> IngredientCategory getIngredientcategoryByID(authorization, xAPIKey, id)

Get Ingredientcategory By ID

Get Ingredientcategory By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    var result = api_instance.getIngredientcategoryByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->getIngredientcategoryByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

[**IngredientCategory**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateIngredientcategoryByID**
> IngredientCategory updateIngredientcategoryByID(authorization, xAPIKey, id, body)

Update Ingredientcategory By ID

Update [object Object] By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 
var body = new IngredientCategory(); // IngredientCategory | 

try { 
    var result = api_instance.updateIngredientcategoryByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->updateIngredientcategoryByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 
 **body** | [**IngredientCategory**](IngredientCategory.md)|  | 

### Return type

[**IngredientCategory**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.2.tar.gz: docs/IngredientCategoryApi.md <==
# swagger.api.IngredientCategoryApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createIngredientcategory**](IngredientCategoryApi.md#createIngredientcategory) | **POST** /ingredient-category | Create Ingredientcategory
[**deleteIngredientcategoryByID**](IngredientCategoryApi.md#deleteIngredientcategoryByID) | **DELETE** /ingredient-category/{id} | Delete Ingredientcategory By ID
[**findIngredientcategory**](IngredientCategoryApi.md#findIngredientcategory) | **GET** /ingredient-category | Get Ingredientcategory List
[**getIngredientcategoryByID**](IngredientCategoryApi.md#getIngredientcategoryByID) | **GET** /ingredient-category/{id} | Get Ingredientcategory By ID
[**updateIngredientcategoryByID**](IngredientCategoryApi.md#updateIngredientcategoryByID) | **PUT** /ingredient-category/{id} | Update Ingredientcategory By ID


# **createIngredientcategory**
> IngredientCategory createIngredientcategory(authorization, xAPIKey, body)

Create Ingredientcategory

Create Ingredientcategory

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new IngredientCategory(); // IngredientCategory | 

try { 
    var result = api_instance.createIngredientcategory(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->createIngredientcategory: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**IngredientCategory**](IngredientCategory.md)|  | 

### Return type

[**IngredientCategory**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteIngredientcategoryByID**
> deleteIngredientcategoryByID(authorization, xAPIKey, id)

Delete Ingredientcategory By ID

Delete Ingredientcategory By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    api_instance.deleteIngredientcategoryByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->deleteIngredientcategoryByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findIngredientcategory**
> List<IngredientCategory> findIngredientcategory(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Ingredientcategory List

Get Ingredientcategory  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findIngredientcategory(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->findIngredientcategory: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<IngredientCategory>**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getIngredientcategoryByID**
> IngredientCategory getIngredientcategoryByID(authorization, xAPIKey, id)

Get Ingredientcategory By ID

Get Ingredientcategory By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    var result = api_instance.getIngredientcategoryByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->getIngredientcategoryByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

[**IngredientCategory**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateIngredientcategoryByID**
> IngredientCategory updateIngredientcategoryByID(authorization, xAPIKey, id, body)

Update Ingredientcategory By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new IngredientCategoryApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 
var body = new IngredientCategory(); // IngredientCategory | 

try { 
    var result = api_instance.updateIngredientcategoryByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling IngredientCategoryApi->updateIngredientcategoryByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 
 **body** | [**IngredientCategory**](IngredientCategory.md)|  | 

### Return type

[**IngredientCategory**](IngredientCategory.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
